function out = lab1_sys2(in)

%function out = lab1_sys2(in)
%
% LAB1_SYS2  --  Corrupts a signal with a lowpass filter
%
% Input parameters:
%   in   -- the signal to be corrupted
%
% Output parameters:
%   out  -- the corrupted signal

% Written by Mark Bartsch, Winter 2002
% Modification History:
%    8/16/02  --  Added modification history (MB)



b = ones(10,1)/10;
out = filtfilt(b,1,in);
